function cannon_64_dir()
	return {
		layers = {
			{
				filename = "__base__/graphics/entity/tank/turret.png",
				line_length = 8,
				width = 92,
				height = 69,
				frame_count = 1,
				direction_count = 64,
				shift = {0.06,-0.48},
				scale = 1.15,
				animation_speed = 8,
			},
			{
				filename = "__base__/graphics/entity/tank/turret-mask.png",
				line_length = 8,
				width = 38,
				height = 29,
				frame_count = 1,
				apply_runtime_tint = true,
				direction_count = 64,
				shift = {0.06, -0.63626},
				scale = 1.15
			},
			{
				filename = "__base__/graphics/entity/tank/turret-shadow.png",
				line_length = 8,
				width = 95,
				height = 67,
				frame_count = 1,
				draw_as_shadow = true,
				direction_count = 64,
				shift = {0.5, 0.35},
				scale = 1.15
			}
		}
	}
end

function cannon_8_dir()
	return {
		layers = {
			{
				filename = "__base__/graphics/entity/tank/turret.png",
				line_length = 1,
				width = 92,
				height = 69,
				frame_count = 1,
				direction_count = 8,
				shift = {0.06,-0.48},
				scale = 1.15,
				animation_speed = 1,
			},
			{
				filename = "__base__/graphics/entity/tank/turret-mask.png",
				line_length = 1,
				width = 38,
				height = 29,
				frame_count = 1,
				apply_runtime_tint = true,
				direction_count = 8,
				shift = {0.06, -0.63626},
				scale = 1.15
			},
			{
				filename = "__base__/graphics/entity/tank/turret-shadow.png",
				line_length = 1,
				width = 95,
				height = 67,
				frame_count = 1,
				draw_as_shadow = true,
				direction_count = 8,
				shift = {0.5, 0.35},
				scale = 1.15
			}
		}
	}
end

function capsule_door(run_mode)	
	return {
		layers = {
			{
				filename = modEntity.. "capsule-dispenser/capsule-door.png",
				line_length = 16,
				width = 52,
				height = 40,
				frame_count = 16,
				direction_count = 1,
				shift = {0.06,-0.48},
				scale = 0.9,
				run_mode = run_mode
			}
		}
	}
end

function capsule_door_open()
	return {
		layers = {
			{
				filename = modEntity.. "capsule-dispenser/capsule-door-open.png",
				line_length = 1,
				width = 52,
				height = 40,
				frame_count = 1,
				direction_count = 1,
				shift = {0.06,-0.48},
				scale = 0.9,
			}
		}
	}
end

function capsule_door_closed()
	return {
		layers = {
			{
				filename = modEntity.. "capsule-dispenser/capsule-door-closed.png",
				line_length = 1,
				width = 52,
				height = 40,
				frame_count = 1,
				direction_count = 1,
				shift = {0.06,-0.48},
				scale = 0.9,
			}
		}
	}
end

data:extend({
  {
    type = "ammo-turret",
    name = "cannon-turret",
    icon = modIcon.."cannon-turret.png",
    flags = {"placeable-player", "player-creation"},
    minable = {mining_time = 0.5, result = "cannon-turret"},
    max_health = 1500,
    resistances =
    {
      {
        type = "fire",
        decrease = 15,
        percent = 50
      },
      {
        type = "physical",
        decrease = 15,
        percent = 30
      },
      {
        type = "impact",
        decrease = 50,
        percent = 60
      },
      {
        type = "explosion",
        decrease = 15,
        percent = 30
      },
      {
        type = "acid",
        decrease = 10,
        percent = 20
      }
    },
    corpse = "medium-remnants",
    collision_box = {{-0.7, -0.7 }, {0.7, 0.7}},
    selection_box = {{-1, -1 }, {1, 1}},
    rotation_speed = 0.015,
    preparing_speed = 0.08,
    folding_speed = 0.08,
    dying_explosion = "medium-explosion",
    inventory_size = 1,
    automated_ammo_count = 10,
    attacking_speed = 0.5,
    folded_animation = cannon_8_dir(),
    preparing_animation = cannon_8_dir(),
    prepared_animation = cannon_64_dir(),
    attacking_animation = cannon_64_dir(),
    folding_animation = cannon_8_dir(),
    base_picture =
    {
      layers =
      {
        {
          filename = "__base__/graphics/entity/gun-turret/gun-turret-base.png",
          priority = "high",
          width = 90,
          height = 75,
          axially_symmetrical = false,
          direction_count = 1,
          shift = {0.0625, -0.046875},
        },
        {
          filename = "__base__/graphics/entity/gun-turret/gun-turret-base-mask.png",
          line_length = 1,
          width = 52,
          height = 47,
          frame_count = 1,
          axially_symmetrical = false,
          direction_count = 1,
          shift = {0.0625, -0.234375},
          apply_runtime_tint = true
        }
      }
    },
    vehicle_impact_sound =  { filename = "__base__/sound/car-metal-impact.ogg", volume = 0.65 },
    attack_parameters =
    {
      type = "projectile",
      ammo_category = "cannon-shell",
      cooldown = 90,
      movement_slow_down_factor = 0,--
      projectile_creation_distance = 1.6,
      projectile_center = {0.06,-0.48},
      damage_modifier = 2,
      range = 25,
      sound =
      {
        {
          filename = "__base__/sound/fight/tank-cannon.ogg",
          volume = 1.0
        }
      },
    }
  },  
  {
    type = "ammo-turret",
    name = "capsule-dispenser",
    icon = modIcon.."capsule-dispenser.png",
    flags = {"placeable-player", "player-creation"},
    minable = {mining_time = 0.5, result = "capsule-dispenser"},
    max_health = 750,
    resistances =
    {
      {
        type = "fire",
        decrease = 15,
        percent = 50
      },
      {
        type = "physical",
        decrease = 15,
        percent = 30
      },
      {
        type = "impact",
        decrease = 50,
        percent = 60
      },
      {
        type = "explosion",
        decrease = 15,
        percent = 30
      },
      {
        type = "acid",
        decrease = 10,
        percent = 20
      }
    },
    corpse = "medium-remnants",
    collision_box = {{-0.7, -0.7 }, {0.7, 0.7}},
    selection_box = {{-1, -1 }, {1, 1}},
    rotation_speed = 0.015,
    preparing_speed = 0.04,
    folding_speed = 0.04,
    dying_explosion = "medium-explosion",
    inventory_size = 1,
    automated_ammo_count = 10,
    attacking_speed = 1,
    folded_animation = capsule_door_closed(),
    preparing_animation = capsule_door("forward"),
    prepared_animation = capsule_door_open(),
    attacking_animation = capsule_door_open(),
    folding_animation = capsule_door("backward"),
    base_picture =
    {
      layers =
      {
        {
          filename = "__base__/graphics/entity/gun-turret/gun-turret-base.png",
          priority = "high",
          width = 90,
          height = 75,
          axially_symmetrical = false,
          direction_count = 1,
          shift = {0.0625, -0.046875},
        },
        {
          filename = "__base__/graphics/entity/gun-turret/gun-turret-base-mask.png",
          line_length = 1,
          width = 52,
          height = 47,
          frame_count = 1,
          axially_symmetrical = false,
          direction_count = 1,
          shift = {0.0625, -0.234375},
          apply_runtime_tint = true
        }
      }
    },
    vehicle_impact_sound =  { filename = "__base__/sound/car-metal-impact.ogg", volume = 0.65 },
    attack_parameters =
    {
      type = "projectile",
      ammo_category = "capsule",
      cooldown = 5*60,
      movement_slow_down_factor = 0,--
      projectile_creation_distance = 0,
      projectile_center = {0.06,-0.48},
      damage_modifier = 1,
      range = 20,
      sound =
      {
        {
          filename = "__base__/sound/roboport-door.ogg",
          volume = 1.0
        }
      },
    }
  },
})