function barbed_wire()
return {
	layers = {
		{
			filename = modEntity.."barbed-wire.png",
			-- run_mode = "forward-then-backward",
			-- line_length = 5,
			width = 288,
			height = 360,
			frame_count = 1,
			-- shift = {scale * 0.09375, scale * -0.046875},
			direction_count = 1,
			scale = 32/288
		}
	}
}
end

function invisible()
return {
	layers = {
		{
			filename = modEntity.."empty.png",
			width = 16,
			height = 16,
			frame_count = 1,
			direction_count = 1
		}
	}
}
end

data:extend({
	{
	type = "wall",
	name = "wire-fence",
	icon = modIcon.."wire-fence.png",
	flags = {"placeable-neutral", "player-creation"},
	collision_box = {{-0.29, -0.29}, {0.29, 0.29}},
	selection_box = {{-0.5, -0.5}, {0.5, 0.5}},
	minable = {mining_time = 0.3, result = "wire-fence"},
	fast_replaceable_group = "wall",
	max_health = 50,
	repair_speed_modifier = 3,
	corpse = "small-remnants",
	repair_sound = { filename = "__base__/sound/manual-repair-simple.ogg" },
	mined_sound = { filename = "__core__/sound/mining-wood-1.ogg", volume = 0.6 },
	vehicle_impact_sound =  { filename = "__base__/sound/car-wood-impact.ogg", volume = 1.0 },
	-- this kind of code can be used for having walls mirror the effect
	-- there can be multiple reaction items
	attack_reaction =
	{
		{
		-- how far the mirroring works
		range = 1.5,
		-- what kind of damage triggers the mirroring
		-- if not present then anything triggers the mirroring
		damage_type = "physical",
		-- caused damage will be multiplied by this and added to the subsequent damages
		reaction_modifier = 0.25,
		action = {
			type = "direct",
			action_delivery = {
				type = "instant",
				target_effects = {
					type = "damage",
					-- always use at least 0.1 damage
					damage = {amount = 1, type = "physical"}
					}
				}
			},
		}
	},
	resistances = {
		{
			type = "physical",
			percent = 30
		},
		{
			type = "impact",
			decrease = 5,
			percent = 10
		},
		{
			type = "explosion",
			decrease = 10,
			percent = 75
		},
		{
			type = "laser",
			percent = 100
		}
		},
	pictures = {
		single = {
			layers = {
				{
					filename = modEntity.."wire-fence/single.png",
					priority = "extra-high",
					width = 22,
					height = 42,
					shift = {0, -0.15625}
				},
				{
					filename = modEntity.."wire-fence/shadow.png",
					priority = "extra-high",
					width = 47,
					height = 32,
					shift = {0.7, 0.25},
					draw_as_shadow = true
				}
				}
			},
		straight_vertical = {
			layers = {
				{
					filename = modEntity.."wire-fence/straight-vertical.png",
					priority = "extra-high",
					width = 22,
					height = 42,
					shift = {0, -0.15625}
				},
				{
					filename = modEntity.."wire-fence/shadow.png",
					priority = "extra-high",
					width = 47,
					height = 32,
					shift = {0.7, 0.25},
					draw_as_shadow = true
				}
				}
			},
		straight_horizontal = {
			layers = {
				{
					filename = modEntity.."wire-fence/straight-horizontal.png",
					priority = "extra-high",
					width = 32,
					height = 42,
					shift = {0, -0.15625}
				},
				{
					filename = modEntity.."wire-fence/shadow.png",
					priority = "extra-high",
					width = 47,
					height = 32,
					shift = {0.7, 0.25},
					draw_as_shadow = true
				}
				}
			},
		corner_right_down = {
			layers = {
				{
					filename = modEntity.."wire-fence/corner-right-down.png",
					priority = "extra-high",
					width = 27,
					height = 42,
					shift = {0.078125, -0.15625}
				},
				{
					filename = modEntity.."wire-fence/shadow.png",
					priority = "extra-high",
					width = 47,
					height = 32,
					shift = {0.7, 0.25},
					draw_as_shadow = true
				}
				}
			},
		corner_left_down = {
			layers = {
				{
					filename = modEntity.."wire-fence/corner-left-down.png",
					priority = "extra-high",
					width = 27,
					height = 42,
					shift = {-0.078125, -0.15625}
				},
				{
					filename = modEntity.."wire-fence/shadow.png",
					priority = "extra-high",
					width = 47,
					height = 32,
					shift = {0.7, 0.25},
					draw_as_shadow = true
				}
				}
			},
		t_up = {
			layers = {
				{
					filename = modEntity.."wire-fence/t-down.png",
					priority = "extra-high",
					width = 32,
					height = 42,
					shift = {0, -0.15625}
				},
				{
					filename = modEntity.."wire-fence/shadow.png",
					priority = "extra-high",
					width = 47,
					height = 32,
					shift = {0.7, 0.25},
					draw_as_shadow = true
				}
				}
			},
		ending_right = {
			layers = {
				{
					filename = modEntity.."wire-fence/ending-right.png",
					priority = "extra-high",
					width = 27,
					height = 42,
					shift = {0.078125, -0.15625}
				},
				{
					filename = modEntity.."wire-fence/shadow.png",
					priority = "extra-high",
					width = 47,
					height = 32,
					shift = {0.7, 0.25},
					draw_as_shadow = true
				}
				}
			},
		ending_left = {
			layers = {
				{
					filename = modEntity.."wire-fence/ending-left.png",
					priority = "extra-high",
					width = 27,
					height = 42,
					shift = {-0.078125, -0.15625}
				},
				{
					filename = modEntity.."wire-fence/shadow.png",
					priority = "extra-high",
					width = 47,
					height = 32,
					shift = {0.7, 0.25},
					draw_as_shadow = true
				}
				}
			}
		}
	}, 
	
	{
    type = "sticker",
    name = "barbed-wire-slowdown",
    flags = {"not-on-map"},
    --icon = "__base__/graphics/icons/slowdown-sticker.png",
    flags = {},
    animation =
    {
      filename = "__base__/graphics/entity/slowdown-sticker/slowdown-sticker.png",
      priority = "extra-high",
      width = 11,
      height = 11,
      frame_count = 13,
      animation_speed = 0.4
    },
    duration_in_ticks = 60,
    magnitude = 0.5
	},
	
	{
	type = "turret",
	name = "barbed-wire",
	icon = modIcon.."barbed-wire.png",
    flags = {"placeable-player", "player-creation"},
	minable = {mining_time = 0.1, result = "barbed-wire"},
	max_health = 50,
	collision_box = {{-0.01, -0.01}, {0.01, 0.01}},
	selection_box = {{-0.5, -0.5 }, {0.5, 0.5}},
	fast_replaceable_group = "wall",
	shooting_cursor_size = 0,
	corpse = "small-remnants",
	folded_animation = barbed_wire(),
	preparing_animation = barbed_wire(),
	prepared_animation = barbed_wire(),
	starting_attack_animation = barbed_wire(),
	ending_attack_animation = barbed_wire(),
	folding_animation =  barbed_wire(),
	attack_parameters = {
		type = "projectile",
		range = 1,
		cooldown = 35,
		ammo_category = "melee",
		ammo_type = {
			category = "melee",
			target_type = "entity",
			action = {
				type = "direct",
				action_delivery = {
					type = "instant",
					target_effects = {
						{
							type = "damage",
							damage = { amount = 3 , type = "physical"}
						},
						{
							type = "create-sticker",
							sticker = "barbed-wire-slowdown"
						}
						}
					}
				}
			}
		},	
	},
	
	{
    type = "electric-pole",
    name = "invisible-pole",
	icon = modIcon.."barbed-wire.png",
    flags = {"placeable-neutral", "not-on-map"},
    max_health = 1,
	collision_box = {{-0.45, -0.45}, {0.45, 0.45}},
	selection_box = {{-0.5, -0.5}, {0.5, 0.5}},
    selectable_in_game = false,
    maximum_wire_distance = 1.5,
    supply_area_distance = 1.5,
    vehicle_impact_sound =  { filename = "__base__/sound/car-metal-impact.ogg", volume = 0.65 },
    pictures =
    {
      filename = modEntity.."empty.png",
      priority = "very-low",
      width = 16,
      height = 16,
      direction_count = 1
    },
    connection_points =
    {
      {
        shadow =
        {
          copper = {1.2, 0.35},
          green = {0, -0.2},
          red = {0, -0.2}
        },
        wire =
        {
          copper = {0, -0.75},
          green = {0,-1},
          red = {0,-1}
        }
      },
    },
    radius_visualisation_picture =
    {
      filename = "__base__/graphics/entity/small-electric-pole/electric-pole-radius-visualization.png",
      width = 12,
      height = 12,
      priority = "extra-high-no-scale"
    },
  },
	
	{
    type = "electric-turret",
    name = "electric-fence-turret",
	icon = modIcon.."electric-fence.png",
    flags = {"placeable-player", "player-creation"},
    minable = { mining_time = 0.5, result = "electric-fence-turret" },
	fast_replaceable_group = "wall",
    max_health = 350,
	repair_sound = { filename = "__base__/sound/manual-repair-simple.ogg" },
	mined_sound = { filename = "__core__/sound/mining-wood-1.ogg", volume = 0.6 },
    repair_speed_modifier = 2,
	corpse = "small-remnants",
	resistances = {
		{
			type = "physical",
			decrease = 3,
			percent = 30
		},
		{
			type = "impact",
			decrease = 5,
			percent = 50
		},
		{
			type = "explosion",
			decrease = 10,
			percent = 75
		},
		{
			type = "laser",
			percent = 100
		}
		},
	collision_box = {{-0.46, -0.46}, {0.46, 0.46}},
	selection_box = {{-0.51, -0.51}, {0.51, 0.51}},
    rotation_speed = 0.01,
    preparing_speed = 0.05,
    dying_explosion = "explosion",
    folding_speed = 0.05,
    energy_source =
    {
      type = "electric",
      buffer_capacity = "801kJ",
      input_flow_limit = "1500kW",
      drain = "500W",
      usage_priority = "primary-input"
    },
    folded_animation = invisible(),
    preparing_animation = invisible(),
    prepared_animation = invisible(),
    folding_animation = invisible(),
    base_picture = {
		layers = {
			{
				filename = modEntity.."electric-fence/single.png",
				priority = "very-low",
				width = 22,
				height = 42,
				shift = {0, -0.15625}
			}
		},
	},
    vehicle_impact_sound =  { filename = "__base__/sound/car-metal-impact.ogg", volume = 0.65 },
    attack_parameters =
    {
      type = "beam",
      ammo_category = "laser-turret",
      cooldown = 60,
      range = 3,
      ammo_type =
      {
        category = "laser-turret",
        energy_consumption = "800kJ",
        action =
        {
          type = "direct",
          action_delivery =
          {
            type = "beam",
            beam = "electric-beam",
            max_length = 3,
            duration = 20,
            source_offset = {0, 0},
          }
        }
      }
    },
  },
  
  {
	type = "wall",
	name = "electric-fence",
	icon = modIcon.."electric-fence.png",
	flags = {"placeable-neutral", "not-on-map"},
	collision_box = {{-0.29, -0.29}, {0.29, 0.29}},
	selection_box = {{-0.5, -0.5}, {0.5, 0.5}},
    selectable_in_game = false,
    max_health = 1,
	vehicle_impact_sound =  { filename = "__base__/sound/car-wood-impact.ogg", volume = 1.0 },
	pictures = {
		single = {
			layers = {
				{
					filename = modEntity.."electric-fence/single.png",
					priority = "extra-high",
					width = 22,
					height = 42,
					shift = {0, -0.15625}
				},
				{
					filename = modEntity.."electric-fence/shadow.png",
					priority = "extra-high",
					width = 47,
					height = 32,
					shift = {0.7, 0.25},
					draw_as_shadow = true
				}
				}
			},
		straight_vertical = {
			layers = {
				{
					filename = modEntity.."electric-fence/straight-vertical.png",
					priority = "extra-high",
					width = 22,
					height = 42,
					shift = {0, -0.15625}
				},
				{
					filename = modEntity.."electric-fence/shadow.png",
					priority = "extra-high",
					width = 47,
					height = 32,
					shift = {0.7, 0.25},
					draw_as_shadow = true
				}
				}
			},
		straight_horizontal = {
			layers = {
				{
					filename = modEntity.."electric-fence/straight-horizontal.png",
					priority = "extra-high",
					width = 32,
					height = 42,
					shift = {0, -0.15625}
				},
				{
					filename = modEntity.."electric-fence/shadow.png",
					priority = "extra-high",
					width = 47,
					height = 32,
					shift = {0.7, 0.25},
					draw_as_shadow = true
				}
				}
			},
		corner_right_down = {
			layers = {
				{
					filename = modEntity.."electric-fence/corner-right-down.png",
					priority = "extra-high",
					width = 27,
					height = 42,
					shift = {0.078125, -0.15625}
				},
				{
					filename = modEntity.."electric-fence/shadow.png",
					priority = "extra-high",
					width = 47,
					height = 32,
					shift = {0.7, 0.25},
					draw_as_shadow = true
				}
				}
			},
		corner_left_down = {
			layers = {
				{
					filename = modEntity.."electric-fence/corner-left-down.png",
					priority = "extra-high",
					width = 27,
					height = 42,
					shift = {-0.078125, -0.15625}
				},
				{
					filename = modEntity.."electric-fence/shadow.png",
					priority = "extra-high",
					width = 47,
					height = 32,
					shift = {0.7, 0.25},
					draw_as_shadow = true
				}
				}
			},
		t_up = {
			layers = {
				{
					filename = modEntity.."electric-fence/t-down.png",
					priority = "extra-high",
					width = 32,
					height = 42,
					shift = {0, -0.15625}
				},
				{
					filename = modEntity.."electric-fence/shadow.png",
					priority = "extra-high",
					width = 47,
					height = 32,
					shift = {0.7, 0.25},
					draw_as_shadow = true
				}
				}
			},
		ending_right = {
			layers = {
				{
					filename = modEntity.."electric-fence/ending-right.png",
					priority = "extra-high",
					width = 27,
					height = 42,
					shift = {0.078125, -0.15625}
				},
				{
					filename = modEntity.."electric-fence/shadow.png",
					priority = "extra-high",
					width = 47,
					height = 32,
					shift = {0.7, 0.25},
					draw_as_shadow = true
				}
				}
			},
		ending_left = {
			layers = {
				{
					filename = modEntity.."electric-fence/ending-left.png",
					priority = "extra-high",
					width = 27,
					height = 42,
					shift = {-0.078125, -0.15625}
				},
				{
					filename = modEntity.."electric-fence/shadow.png",
					priority = "extra-high",
					width = 47,
					height = 32,
					shift = {0.7, 0.25},
					draw_as_shadow = true
				}
				}
			}
		}
	}, 
	
	-- {
    -- type = "wall",
    -- name = "self-repairing-wall",
    -- icon = modIcon.."self-repairing-wall.png",
    -- flags = {"placeable-neutral", "player-creation"},
    -- collision_box = {{-0.29, -0.29}, {0.29, 0.29}},
    -- selection_box = {{-0.5, -0.5}, {0.5, 0.5}},
    -- minable = {mining_time = 1, result = "self-repairing-wall"},
    -- fast_replaceable_group = "wall",
    -- max_health = 350,
    -- repair_speed_modifier = 1/2,
    -- corpse = "wall-remnants",
    -- repair_sound = { filename = "__base__/sound/manual-repair-simple.ogg" },
    -- mined_sound = { filename = "__base__/sound/deconstruct-bricks.ogg" },
    -- vehicle_impact_sound =  { filename = "__base__/sound/car-stone-impact.ogg", volume = 1.0 },
    -- resistances =
    -- {
      -- {
        -- type = "physical",
        -- decrease = 3,
        -- percent = 20
      -- },
      -- {
        -- type = "impact",
        -- decrease = 45,
        -- percent = 60
      -- },
      -- {
        -- type = "explosion",
        -- decrease = 10,
        -- percent = 30
      -- },
      -- {
        -- type = "fire",
        -- percent = 100
      -- },
      -- {
        -- type = "laser",
        -- percent = 70
      -- }
    -- },
    -- healing_per_tick = 1/6,
    -- pictures =
    -- {
      -- single =
      -- {
        -- layers =
        -- {
          -- {
            -- filename = modEntity.."self-repairing-wall/wall-single.png",
            -- priority = "extra-high",
            -- width = 22,
            -- height = 42,
            -- shift = {0, -0.15625}
          -- },
          -- {
            -- filename = "__base__/graphics/entity/stone-wall/wall-single-shadow.png",
            -- priority = "extra-high",
            -- width = 47,
            -- height = 32,
            -- shift = {0.359375, 0.5},
            -- draw_as_shadow = true
          -- }
        -- }
      -- },
      -- straight_vertical =
      -- {
        -- {
          -- layers =
          -- {
            -- {
              -- filename = modEntity.."self-repairing-wall/wall-straight-vertical-1.png",
              -- priority = "extra-high",
              -- width = 22,
              -- height = 42,
              -- shift = {0, -0.15625}
            -- },
            -- {
              -- filename = "__base__/graphics/entity/stone-wall/wall-straight-vertical-shadow.png",
              -- priority = "extra-high",
              -- width = 47,
              -- height = 60,
              -- shift = {0.390625, 0.625},
              -- draw_as_shadow = true
            -- }
          -- }
        -- },
        -- {
          -- layers =
          -- {
            -- {
              -- filename = modEntity.."self-repairing-wall/wall-straight-vertical-2.png",
              -- priority = "extra-high",
              -- width = 22,
              -- height = 42,
              -- shift = {0, -0.15625}
            -- },
            -- {
              -- filename = "__base__/graphics/entity/stone-wall/wall-straight-vertical-shadow.png",
              -- priority = "extra-high",
              -- width = 47,
              -- height = 60,
              -- shift = {0.390625, 0.625},
              -- draw_as_shadow = true
            -- }
          -- }
        -- },
        -- {
          -- layers =
          -- {
            -- {
              -- filename = modEntity.."self-repairing-wall/wall-straight-vertical-3.png",
              -- priority = "extra-high",
              -- width = 22,
              -- height = 42,
              -- shift = {0, -0.15625}
            -- },
            -- {
              -- filename = "__base__/graphics/entity/stone-wall/wall-straight-vertical-shadow.png",
              -- priority = "extra-high",
              -- width = 47,
              -- height = 60,
              -- shift = {0.390625, 0.625},
              -- draw_as_shadow = true
            -- }
          -- }
        -- }
      -- },
      -- straight_horizontal =
      -- {
        -- {
          -- layers =
          -- {
            -- {
              -- filename = modEntity.."self-repairing-wall/wall-straight-horizontal-1.png",
              -- priority = "extra-high",
              -- width = 32,
              -- height = 42,
              -- shift = {0, -0.15625}
            -- },
            -- {
              -- filename = "__base__/graphics/entity/stone-wall/wall-straight-horizontal-shadow.png",
              -- priority = "extra-high",
              -- width = 59,
              -- height = 32,
              -- shift = {0.421875, 0.5},
              -- draw_as_shadow = true
            -- }
          -- }
        -- },
        -- {
          -- layers =
          -- {
            -- {
              -- filename = modEntity.."self-repairing-wall/wall-straight-horizontal-2.png",
              -- priority = "extra-high",
              -- width = 32,
              -- height = 42,
              -- shift = {0, -0.15625}
            -- },
            -- {
              -- filename = "__base__/graphics/entity/stone-wall/wall-straight-horizontal-shadow.png",
              -- priority = "extra-high",
              -- width = 59,
              -- height = 32,
              -- shift = {0.421875, 0.5},
              -- draw_as_shadow = true
            -- }
          -- }
        -- },
        -- {
          -- layers =
          -- {
            -- {
              -- filename = modEntity.."self-repairing-wall/wall-straight-horizontal-3.png",
              -- priority = "extra-high",
              -- width = 32,
              -- height = 42,
              -- shift = {0, -0.15625}
            -- },
            -- {
              -- filename = "__base__/graphics/entity/stone-wall/wall-straight-horizontal-shadow.png",
              -- priority = "extra-high",
              -- width = 59,
              -- height = 32,
              -- shift = {0.421875, 0.5},
              -- draw_as_shadow = true
            -- }
          -- }
        -- }
      -- },
      -- corner_right_down =
      -- {
        -- layers =
        -- {
          -- {
            -- filename = modEntity.."self-repairing-wall/wall-corner-right-down.png",
            -- priority = "extra-high",
            -- width = 27,
            -- height = 42,
            -- shift = {0.078125, -0.15625}
          -- },
          -- {
            -- filename = "__base__/graphics/entity/stone-wall/wall-corner-right-down-shadow.png",
            -- priority = "extra-high",
            -- width = 53,
            -- height = 61,
            -- shift = {0.484375, 0.640625},
            -- draw_as_shadow = true
          -- }
        -- }
      -- },
      -- corner_left_down =
      -- {
        -- layers =
        -- {
          -- {
            -- filename = modEntity.."self-repairing-wall/wall-corner-left-down.png",
            -- priority = "extra-high",
            -- width = 27,
            -- height = 42,
            -- shift = {-0.078125, -0.15625}
          -- },
          -- {
            -- filename = "__base__/graphics/entity/stone-wall/wall-corner-left-down-shadow.png",
            -- priority = "extra-high",
            -- width = 53,
            -- height = 60,
            -- shift = {0.328125, 0.640625},
            -- draw_as_shadow = true
          -- }
        -- }
      -- },
      -- t_up =
      -- {
        -- layers =
        -- {
          -- {
            -- filename = modEntity.."self-repairing-wall/wall-t-down.png",
            -- priority = "extra-high",
            -- width = 32,
            -- height = 42,
            -- shift = {0, -0.15625}
          -- },
          -- {
            -- filename = "__base__/graphics/entity/stone-wall/wall-t-down-shadow.png",
            -- priority = "extra-high",
            -- width = 71,
            -- height = 61,
            -- shift = {0.546875, 0.640625},
            -- draw_as_shadow = true
          -- }
        -- }
      -- },
      -- ending_right =
      -- {
        -- layers =
        -- {
          -- {
            -- filename = modEntity.."self-repairing-wall/wall-ending-right.png",
            -- priority = "extra-high",
            -- width = 27,
            -- height = 42,
            -- shift = {0.078125, -0.15625}
          -- },
          -- {
            -- filename = "__base__/graphics/entity/stone-wall/wall-ending-right-shadow.png",
            -- priority = "extra-high",
            -- width = 53,
            -- height = 32,
            -- shift = {0.484375, 0.5},
            -- draw_as_shadow = true
          -- }
        -- }
      -- },
      -- ending_left =
      -- {
        -- layers =
        -- {
          -- {
            -- filename = modEntity.."self-repairing-wall/wall-ending-left.png",
            -- priority = "extra-high",
            -- width = 27,
            -- height = 42,
            -- shift = {-0.078125, -0.15625}
          -- },
          -- {
            -- filename = "__base__/graphics/entity/stone-wall/wall-ending-left-shadow.png",
            -- priority = "extra-high",
            -- width = 53,
            -- height = 32,
            -- shift = {0.328125, 0.5},
            -- draw_as_shadow = true
          -- }
        -- }
      -- }
    -- }
  -- },
})

